@@ -1,8 +1,8 @@
 #! /bin/sh
 
 if [ "$1" = "copy" ]; then
-    for i in externalmodules/*; do
-        cp -r $i modules
+    for i in externalplugins/*; do
+        cp -r $i plugins
     done
 
     for i in externalthemes/emoticons/*; do
@@ -12,8 +12,8 @@ if [ "$1" = "copy" ]; then
         cp -r $i varia/themes/sounds
     done
 elif [ "$1" = "remove" ]; then
-    for i in externalmodules/*; do
-        rm -rf modules/${i##*/}
+    for i in externalplugins/*; do
+        rm -rf plugins/${i##*/}
     done
 
     for i in externalthemes/emoticons/*; do
